pub struct NetworkEngineeringApi { /* private fields */ }Expand description
Network Engineering package — 7 endpoints.
Implementations
Sourceimpl NetworkEngineeringApi
impl NetworkEngineeringApi
pub fn new(http: HttpClient) -> Self
Sourcepub fn get_asn_info_full(
&self,
asn: &str,
locality_language: &str,
) -> Result<AsnInfoFullResponse>
pub fn get_asn_info_full( &self, asn: &str, locality_language: &str, ) -> Result<AsnInfoFullResponse>
Returns extended ASN info including peers, transit, prefix counts, and service area.
Sourcepub fn get_receiving_from(
&self,
asn: &str,
batch_size: u32,
offset: u32,
locality_language: &str,
) -> Result<AsnInfoFullResponse>
pub fn get_receiving_from( &self, asn: &str, batch_size: u32, offset: u32, locality_language: &str, ) -> Result<AsnInfoFullResponse>
Returns paginated upstream providers (ASNs this ASN receives traffic from).
Sourcepub fn get_transit_to(
&self,
asn: &str,
batch_size: u32,
offset: u32,
locality_language: &str,
) -> Result<AsnInfoFullResponse>
pub fn get_transit_to( &self, asn: &str, batch_size: u32, offset: u32, locality_language: &str, ) -> Result<AsnInfoFullResponse>
Returns paginated downstream peers (ASNs this ASN provides transit to).
Sourcepub fn get_bgp_prefixes(
&self,
asn: &str,
ipv4: bool,
batch_size: u32,
offset: u32,
) -> Result<PrefixesListResponse>
pub fn get_bgp_prefixes( &self, asn: &str, ipv4: bool, batch_size: u32, offset: u32, ) -> Result<PrefixesListResponse>
Returns paginated active BGP prefixes for an ASN. Set ipv4 = false for IPv6.
Sourcepub fn get_networks_by_cidr(
&self,
cidr: &str,
locality_language: &str,
) -> Result<NetworkByCidrResponse>
pub fn get_networks_by_cidr( &self, cidr: &str, locality_language: &str, ) -> Result<NetworkByCidrResponse>
Returns all networks announced on BGP within a CIDR range.
Sourcepub fn get_asn_rank_list(
&self,
batch_size: u32,
offset: u32,
) -> Result<AsnRankListResponse>
pub fn get_asn_rank_list( &self, batch_size: u32, offset: u32, ) -> Result<AsnRankListResponse>
Returns a paginated ranked list of all ASNs by IPv4 address space.
Sourcepub fn get_tor_exit_nodes(
&self,
batch_size: u32,
offset: u32,
) -> Result<TorExitNodesResponse>
pub fn get_tor_exit_nodes( &self, batch_size: u32, offset: u32, ) -> Result<TorExitNodesResponse>
Returns a paginated list of active Tor exit nodes.